@@ -13,7 +13,7 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.911';
+our $VERSION = '0.912';
 
 has client => (
     is       => 'ro',
@@ -72,7 +72,7 @@ has destination => (
             || $ENV{PGDATABASE}
             || $self->username
             || $ENV{PGUSER}
-            || $ENV{USER};
+            || $self->sqitch->sysuser
     },
 );
 
